# Filter

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**action** | [**FilterAction**](FilterAction.md) |  | [optional] 
**criteria** | [**FilterCriteria**](FilterCriteria.md) |  | [optional] 
**id** | **str** | The server assigned ID of the filter. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

